# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/32_embs.ipynb.

# %% auto 0
__all__ = ['X', 'X_', 'X_MAGIC', 'X_PCA', 'X_PCA_HVG', 'X_PHATE', 'X_PHATE_HVG']

# %% ../nbs/32_embs.ipynb 4
from nchr import S_
from .mthd import MAGIC, PCA, PHATE
from .biol import X, X_, HVG

# %% ../nbs/32_embs.ipynb 5
X = 'X'
X_ = f'{X}{S_}'

# %% ../nbs/32_embs.ipynb 7
# Layer storing MAGIC embedding in adata.obsm
X_MAGIC = f'{X_}{MAGIC}'

# Layer storing PCA embedding in adata.obsm
X_PCA = f'{X_}{PCA}'

# Layer storing PCA embedding just on HVGs in adata.obsm
X_PCA_HVG = f'{X_}{PCA}_{HVG}'

# Layer storing PHATE embedding just in adata.obsm
X_PHATE = f'{X_}{PHATE}'

# Layer storing PHATE embedding just on HVGs in adata.obsm
X_PHATE_HVG = f'{X_}{PHATE}_{HVG}'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/60_narr.ipynb.

# %% auto 0
__all__ = ['NDIM', 'DIMS', 'DTYPE', 'SHAPE', 'TOARRAY', 'TODENSE', 'TOLIST']

# %% ../nbs/60_narr.ipynb 5
NDIM = 'ndim'
DIMS = 'dims'

DTYPE = 'dtype'
SHAPE = 'shape'

TOARRAY = 'toarray'
TODENSE = 'todense'
TOLIST = 'tolist'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/31_mthd.ipynb.

# %% auto 0
__all__ = ['DPT', 'PCA', 'UMAP', 'TSNE', 'PHATE', 'MAGIC', 'PSEUDOTIME', 'DPT_PSEUDOTIME']

# %% ../nbs/31_mthd.ipynb 4
from nchr import S_
from .exps import TIME

# %% ../nbs/31_mthd.ipynb 6
DPT   = 'dpt'
PCA   = 'pca'
UMAP  = 'umap'
TSNE  = 'tsne'
PHATE = 'phate'
MAGIC = 'magic'

# %% ../nbs/31_mthd.ipynb 7
PSEUDOTIME = f'pseudo{TIME}'
DPT_PSEUDOTIME = f'{DPT}{S_}{PSEUDOTIME}'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/61_tens.ipynb.

# %% auto 0
__all__ = ['DETACH', 'DEVICE', 'CUDA', 'MPS', 'CPU', 'IPU', 'XPU', 'TPU', 'MKLDNN', 'OPENGL', 'OPENCL', 'VULKAN', 'IDEEP', 'HIP',
           'VE', 'FPGA', 'ORT', 'XLA', 'LAZY', 'META', 'HPU', 'PRIVATEUSEONE', 'CLONE', 'NUMPY']

# %% ../nbs/61_tens.ipynb 5
DETACH = 'detach'
DEVICE = 'device'

# %% ../nbs/61_tens.ipynb 7
CUDA = 'cuda'
MPS = 'mps'
CPU = 'cpu'
IPU = 'ipu'
XPU = 'xpu'
TPU = 'tpu'
MKLDNN = 'mkldnn'
OPENGL = 'opengl'
OPENCL = 'opencl'
VULKAN = 'vulkan'
IDEEP = 'ideep'
HIP = 'hip'
VE = 've'
FPGA = 'fpga'
ORT = 'ort'
XLA = 'xla'
LAZY = 'lazy'
META = 'meta'
HPU = 'hpu'
PRIVATEUSEONE = 'privateuseone'

# %% ../nbs/61_tens.ipynb 9
CLONE = 'clone'
DETACH = 'detach'
NUMPY = 'numpy'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/30_exps.ipynb.

# %% auto 0
__all__ = ['ID', 'ITEM', 'NAME', 'SEED', 'BATCH', 'TOTAL', 'PCT', 'PERCENT', 'DAY', 'TIME', 'TIMEPOINT', 'TIMEPOINTS', 'COUNT',
           'NORM', 'NORMALIZED', 'CON', 'CONDITION', 'CONDITIONS', 'SAMPLE', 'SAMPLES', 'TREATMENT', 'TREATMENTS',
           'SENS', 'SENSITIVITY', 'SENSITIVITIES']

# %% ../nbs/30_exps.ipynb 4
from nchr import S_

# %% ../nbs/30_exps.ipynb 6
ID = 'id'

# %% ../nbs/30_exps.ipynb 7
ITEM = 'item'
NAME = 'name'
SEED = 'seed'

# %% ../nbs/30_exps.ipynb 8
BATCH = 'batch'
TOTAL = 'total'

# %% ../nbs/30_exps.ipynb 9
PCT = 'pct'
PERCENT = 'percent'

# %% ../nbs/30_exps.ipynb 10
DAY = 'day'
TIME = 'time'
TIMEPOINT = f'{TIME}point'
TIMEPOINTS = f'{TIMEPOINT}s'

# %% ../nbs/30_exps.ipynb 11
COUNT = 'count'

# %% ../nbs/30_exps.ipynb 12
NORM = 'norm'
NORMALIZED = f'{NORM}alized'

# %% ../nbs/30_exps.ipynb 13
CON = 'con'
CONDITION = f'{CON}dition'
CONDITIONS = f'{CONDITION}s'

# %% ../nbs/30_exps.ipynb 14
SAMPLE = 'sample'
SAMPLES = f'{SAMPLE}s'

# %% ../nbs/30_exps.ipynb 15
TREATMENT = f'treatment'
TREATMENTS = f'{TREATMENT}s'

# %% ../nbs/30_exps.ipynb 16
SENS = 'sens'
SENSITIVITY = f'{SENS}itivity'
SENSITIVITIES = f'{SENS}itivities'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/02_args.ipynb.

# %% auto 0
__all__ = ['N', 'IDX', 'SEP', 'FMT', 'ATTR', 'DESC', 'FUNC', 'KIND', 'TYPE', 'REPR', 'OPTS', 'SHOW', 'PREF', 'LINK', 'HUSH',
           'QUIET', 'RAISE', 'FAILQ', 'SPEC', 'SPECS', 'DEBUG', 'PRINT', 'VALUE', 'CUTOFF', 'MIXINS', 'UNIQUE',
           'HIDDEN', 'IGNORE', 'DEFAULT', 'INPLACE', 'VERBOSE', 'OPTIONAL', 'REQUIRED', 'ASMEMBER', 'ABRV', 'SYMB',
           'CONS', 'FMTFUNC', 'MOD', 'PKG', 'BEG', 'END', 'POS', 'NEG', 'LEN', 'DIG', 'BRV', 'FIX', 'OVERWRITE',
           'OVERWRITABLE']

# %% ../nbs/02_args.ipynb 5
N = 'n'

# %% ../nbs/02_args.ipynb 6
IDX = 'idx'
SEP = 'sep'
FMT = 'fmt'

# %% ../nbs/02_args.ipynb 7
ATTR = 'attr'
DESC = 'desc'
FUNC = 'func'
KIND = 'kind'
TYPE = 'type'
REPR = 'repr'
OPTS = 'opts'
SHOW = 'show'
PREF = 'pref'

# %% ../nbs/02_args.ipynb 8
LINK = 'link'

# %% ../nbs/02_args.ipynb 9
HUSH = 'hush'
QUIET = 'quiet'
RAISE = 'raise'
FAILQ = 'failq'

# %% ../nbs/02_args.ipynb 10
SPEC = 'spec'
SPECS = f'{SPEC}s'

# %% ../nbs/02_args.ipynb 11
DEBUG = 'debug'
PRINT = 'print'
VALUE = 'value'

# %% ../nbs/02_args.ipynb 12
CUTOFF = 'cutoff'
MIXINS = 'mixins'
UNIQUE = 'unique'

# %% ../nbs/02_args.ipynb 13
HIDDEN = 'hidden'
IGNORE = 'ignore'

# %% ../nbs/02_args.ipynb 14
DEFAULT = 'default'
INPLACE = 'inplace'
VERBOSE = 'verbose'

# %% ../nbs/02_args.ipynb 15
OPTIONAL = 'optional'
REQUIRED = 'required'

# %% ../nbs/02_args.ipynb 17
ASMEMBER = 'asmember'

# %% ../nbs/02_args.ipynb 19
ABRV = 'abrv'
SYMB = 'symb'

CONS = 'cons'

# %% ../nbs/02_args.ipynb 20
FMTFUNC = f'{FMT}{FUNC}'

# %% ../nbs/02_args.ipynb 23
MOD = 'mod'
PKG = 'pkg'

# %% ../nbs/02_args.ipynb 25
BEG = 'beg' # beginning
END = 'end' # end / ending

POS = 'pos' # positive
NEG = 'neg' # nevative

LEN = 'len' # length
DIG = 'dig' # digits

BRV = 'brv' # brv / abbreviation
FIX = 'fix' # prefix / suffix

# %% ../nbs/02_args.ipynb 27
OVERWRITE = 'overwrite'
OVERWRITABLE = 'overwritable'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/101_hrdw.ipynb.

# %% auto 0
__all__ = ['GPFS', 'GIBBS', 'IZALITH', 'MCCLEARY']

# %% ../nbs/101_hrdw.ipynb 6
GPFS = 'gpfs'
GIBBS = 'gibbs'
IZALITH = 'izalith'
MCCLEARY = 'mccleary'
